# Cosmic Toolkit
<a href="https://github.com/RonquilloAeon/migri/actions" target="_blank">
    <img src="https://github.com/fsgsmartbuildings/cosmic-toolkit/workflows/Tests/badge.svg" alt="Tests workflow status">
</a>

**Cosmic Toolkit is an opinionated toolkit to speed up the development of complex apps.**

This toolkit is inspired by [Cosmic Python](https://www.cosmicpython.com/).

**Currently in alpha, so proceed with caution!**

## Example usage

There's a fairly complete example of how to use this package in
`./test/test_message_bus.py`.
